@@ -649,7 +649,7 @@ geos_op2_df = function(x, y, geoms) {
 # after checking identical crs,
 # call geos_op2 function op on x and y:
 # DE-9IM compliant should use model = "closed", more robust seems:
-geos_op2_geom = function(op, x, y, s2_model = "semi-open", ...) {
+geos_op2_geom = function(op, x, y, model = "semi-open", ...) {
 	stopifnot(st_crs(x) == st_crs(y))
 	x = st_geometry(x)
 	y = st_geometry(y)
@@ -660,7 +660,7 @@ geos_op2_geom = function(op, x, y, s2_model = "semi-open", ...) {
 				sym_difference = s2::s2_sym_difference,
 				union = s2::s2_union, stop("invalid operator"))
 		# to be optimized -- this doesn't index on y:
-		lst = structure(unlist(lapply(y, function(yy) fn(x, yy, s2::s2_options(model = s2_model, ...))),
+		lst = structure(unlist(lapply(y, function(yy) fn(x, yy, s2::s2_options(model = model, ...))),
 			recursive = FALSE), class = "s2_geography")
 		e = s2::s2_is_empty(lst)
 		idx = cbind(rep(seq_along(x), length(y)), rep(seq_along(y), each = length(x)))
@@ -696,6 +696,8 @@ get_first_sfg = function(x) {
 #' @export
 #' @note To find whether pairs of simple feature geometries intersect, use
 #' the function \code{\link{st_intersects}} instead of \code{st_intersection}.
+#'
+#' When using GEOS and not using s2 polygons contain their boundary. When using s2 this is determined by the \code{model} defaults of \link[s2]{s2_options}, which can be overriden via the ... argument, e.g. \code{model = "closed"} to force DE-9IM compliant behaviour of polygons (and reproduce GEOS results).
 #' @examples
 #' set.seed(131)
 #' library(sf)
