@@ -2,3 +2,5 @@ void set_error_handler(void);
 void unset_error_handler(void);
 OGRSpatialReference *handle_axis_order(OGRSpatialReference *sr);
 Rcpp::List create_crs(const OGRSpatialReference *ref, bool set_input);
+Rcpp::CharacterVector wkt_from_spatial_reference(const OGRSpatialReference *srs);
+int srid_form_crs(Rcpp::List crs);
